@@ -1,7 +1,7 @@
 //#define XERR
 #include "functions.ih"
 
-inline string const &Functions::name() const
+inline std::string const &Functions::name() const
 {
     return isMain() ? s_main : d_overload->first;
 }
