@@ -4,5 +4,5 @@
 void Dependencies::touchUseAll() const
 {
     if (d_options.go() == GO)
-        Exception::factory<ofstream>(d_useAll);
+        Exception::factory<ofstream>(d_useAll); // touch by creating the file
 }
