@@ -1,4 +1,4 @@
-#define XERR
+#define XERR "execute"
 #include "execute.ih"
 
 bool Execute::run(string const &cmd)
