@@ -1,4 +1,4 @@
-#define XERR
+#define XERR "handler"
 #include "handler.ih"
 
 int Handler::spch() const
