@@ -1,4 +1,4 @@
-#define XERR
+#define XERR "icmpp"
 #include "icmpp.ih"
 
 int IcmPp::run()
