@@ -1,4 +1,4 @@
-#define XERR
+#define XERR "."
 #include "main.ih"
 
 int main(int argc, char **argv)
