@@ -1,7 +1,10 @@
-#define XERR
+#define XERR "options"
 #include "options.ih"
 
     // determine the requested action from the initial option(s)/argument(s)
+
+    // by options1.cc
+
 void Options::arguments()
 {
     // initially optind == 1, so it skips the program name
@@ -13,11 +16,9 @@ void Options::arguments()
     separateActionOpts();       // e.g., -dVVV becomes -d -VVV,
                                 // but not for -txx, which becomes -t xx
 
-
     OptLong &opts = 
                 OptLong::init(d_argv, 1, s_actionOptChars, s_actionLongOpts);
 
-
     int key;
     do                          // argv must point to modifiable chars:
     {                           // 'char *const *'
