@@ -1,11 +1,12 @@
-#define XERR
+#define XERR "precompopts"
 #include "precompopts.ih"
 
+// optind specifies the index of the *next* argument processed by
+// getopt_long. When reset to 0 argv[0] must point to a value which
+// is ignored by getopt_long, whereafter remaining options and arguments
+// follow.
 
-    // optind specifies the index of the *next* argument processed by
-    // getopt_long. When reset to 0 argv[0] must point to a value which
-    // is ignored by getopt_long, whereafter remaining options and arguments
-    // follow.
+    // by sourcescript/compile.cc
 
 PreCompOpts::PreCompOpts(PtrVect &argv, char const *options, Action action)
 :
