@@ -1,8 +1,10 @@
-#define XERR
+#define XERR "scriptopts"
 #include "scriptopts.ih"
 
-    // fills (d_)argv with -t's arguments (d_orgArgs[1])
-    // when called the constructor has just cleared (d_)argv
+// fills (d_)argv with -t's arguments (d_orgArgs[1])
+// when called the constructor has just cleared (d_)argv
+
+    // by scriptopts1.cc
 
 void ScriptOpts::reset()                 // d_argv is OptsBase's d_argv
 {
