@@ -8,7 +8,7 @@ namespace FBB
     class TempStream;
 }
 
-class ScriptOpts: public STBase
+class ScriptOpts: public STBase     // with -t, with -s SourceOpts is used
 {
     PtrVect     d_orgArgs;
 
@@ -24,22 +24,23 @@ class ScriptOpts: public STBase
         ~ScriptOpts() override;
 
     private:
+        void addArguments();        // add arguments, including filenames
+
                                     // reset may change tmpDir(), puts all
                                     // remaining -t options in argv and sets
                                     // d_bimName
         void reset();               // d_argv is OptsBase's d_argv
 
-        void setOptions();          // set compile/execute options      // .ih
-        void addArguments();        // add arguments, including filenames
-
                                         // may change tmpDir()
         void setBim(std::string arg1);  // 1st -t argument
 
+        void setOptions();          // set compile/execute options      // .ih
+
         void addImAndBim();
         char *imName();
         char *bimName();
 
-        void tmpBim(std::string const &base);
+        void tmpBim();
 
         void addBeyondNonOpt();     // add options beyond the 1st non-opt
         void addCmdlineArgs();
