@@ -1,10 +1,12 @@
-#define XERR
+#define XERR "scriptopts"
 #include "scriptopts.ih"
 
-    //  the #! arguments: [0]: the binary
-    //                    [1]: 1st line starting at -t
-    //                    [2]: the name of the script using -t
-    //                    [3...]: command-line argument if specified.
+//  the #! arguments: [0]: the binary
+//                    [1]: 1st line starting at -t
+//                    [2]: the name of the script using -t
+//                    [3...]: command-line argument if specified.
+
+    // by options/script.cc
 
 ScriptOpts::ScriptOpts(PtrVect &argv)
 :
