@@ -1,6 +1,8 @@
-#define XERR
+#define XERR "sourceopts"
 #include "sourceopts.ih"
 
+    // by options/source.cc
+
 SourceOpts::SourceOpts(PtrVect &argv)
 :
     STBase(argv),
@@ -16,7 +18,6 @@ SourceOpts::SourceOpts(PtrVect &argv)
     addBimArgs(idx + 1);            // add arguments for the bim file
 
     OptLong::setNextIdx(0);
-
 //show("sourceopts/sourceopts1  compile opts: ", d_compile, false);
 }
 
