@@ -6,7 +6,5 @@ Arg &Arg::initialize(int accept, char const *optstring,
     if (s_arg)
         throw Exception{} << s_alreadyInitialized;
 
-    s_arg.reset(new Arg(accept, optstring, 0, 0, argc, argv));
-
-    return *s_arg;
+    return init(accept, optstring, 0, 0, argc, argv);
 }
