@@ -1,11 +1,16 @@
-#define XERR
+#define XERR "dependencies"
 #include "dependencies.ih"
 
     // called from modules/modules.f
 
-    // d_circular contains the d_imports from the d_modVect modules
-    // d_idx[idx] initially contains indices 0..N, but is partitioned 
-    // so that 0-importing indices are from 0..first
+// d_circular contains the d_imports sets from the d_modVect modules
+// d_idx[idx] initially contains indices 0..N. 
+//
+// It is reordered so that its elements 0..x contain the indices of the
+// modules having 0 dependencies, then the indices of modules having <=
+// 1 dependencies, then <= 2 dependencies etc.
+// After each reordering 
+// partitioned so that 0-importing indices are from 0..first
 
 bool Dependencies::circular()
 {
@@ -19,7 +24,7 @@ bool Dependencies::circular()
                     partition(from, d_idx.end(), 
                         [&](size_t idx)
                         {
-                            return d_circular[d_idx[idx]].size() == 0;
+                            return d_circular[idx].size() == 0;
                         }
                     );
 
@@ -37,3 +42,10 @@ bool Dependencies::circular()
                                         // d_circular
     }
 }
+
+
+
+
+
+
+
