@@ -7,7 +7,7 @@ void Modules::inspect(Classes::Info const &info)
 {
     imsg << "Inspecting " << info.subdir << '/' << endl;
 
-    fs::current_path(info.subdir);              // the source file's dir
+    setDir(info.subdir);                        // the source file's dir
 
     if (not fs::exists("gcm.cache"))            // ln -sf to main's gcm.cache
     {
@@ -20,12 +20,16 @@ void Modules::inspect(Classes::Info const &info)
     for (auto const &entry: fs::directory_iterator{ "." })
     {
         if (
-            fs::path const &src = entry.path(); 
-            src.extension() == d_extension      // a requested source file
+            fs::path const &src = entry.path();             // a requested 
+            src.extension() == d_options.extension()        // source file
         )
             d_scan.process(info.subdir, src.string().substr(2));
     }
 
-    fs::current_path(d_scan.cwd());
+    setDir(d_cwd);
 }
 
+
+
+
+
