@@ -8,22 +8,12 @@
 //      F           T           compile
 
 Modules::Modules()
+:
+    d_options(Options::instance()),
+    d_cwd(fs::current_path()),
+    d_scan(d_modVect, d_modNameIdx),
+    d_dependencies(d_idx, d_modVect, d_modNameIdx)
 {
-    Arg const &arg = Arg::instance();
-
-    inspectVerbose(arg);                    // also sets d_dependencies
-
-    if (arg.nArgs() == 0)
-        d_clean = false;
-    else
-    {
-        if (arg[0] != "clean"s)
-            throw Exception{} << "argument " << arg[0] << " not supported";
-        d_clean = true;
-        return;                             // action 'clean' requested
-    }
-
-    setExtension(arg);
                                             // if already exist, false but
     fs::create_directory("gcm.cache", s_errorCode);     // error_code == 0
 
@@ -32,3 +22,6 @@ Modules::Modules()
     createSymlink("/usr", "gcm.cache/usr");
 }
 
+
+
+
