@@ -7,7 +7,7 @@
 size_t Scan::declare(string const &name)
 {
     if (
-        auto inserted = d_moduleNameIdx.insert({ name, d_modVect.size() });
+        auto inserted = d_modNameIdx.insert({ name, d_modVect.size() });
         not inserted.second         // not .second? then existed
     )
         return idxOf(inserted);
