@@ -3,14 +3,15 @@
 
     // called by modules/inspect.cc
 
-    // sourcePath the path to reach filename fm d_cwd
+    // sourcePath the path to reach filename fm the project's top-level dir.
 
 void Scan::process(std::string const &subdir, string const &filename)
 {
     (d_sourcePath = subdir) /= filename;
 
     d_exportNeeded = false;         // set to true by defineModule
-    d_currentIdx = ~0L;             // reset the idx: no module defined yet
+    d_nameIdx = ~0UL;               // reset the idx: no available module name
+    d_currentIdx = ~0UL;            // reset the idx: no module defined yet
                                     // by this source
 
     imsg << "   scanning " << filename << endl;
@@ -24,7 +25,7 @@ void Scan::process(std::string const &subdir, string const &filename)
             return;
 
             case Scanner::MODDEF:               // export module Name;
-                defineModule();
+               defineModule();
             continue;
 
             case Scanner::PARTDEF:              // export module Name:Part;
@@ -32,16 +33,16 @@ void Scan::process(std::string const &subdir, string const &filename)
             continue;
 
             case Scanner::MODDECL:              // [export] import Other; 
-                declareModule();
+                importModule();
+            continue;
+
+            case Scanner::PARTDECL:             // [export] import :Part;
+                importPartition();
             continue;
 
             case Scanner::MODSRC:               // module Name;
-                source();
-            continue;
-
-            case Scanner::PARTDECL:             // export import :Part;
-                declarePartition();
-            continue;
+                modSource();
+            continue;      
         }
     }
-}    
+}
