@@ -17,6 +17,9 @@ namespace
 int main(int argc, char **argv)
 try
 {
+    emsg.setTag("icm-multicomp error");
+    wmsg.setTag("icm-multicomp warning");
+
     Arg const &arg = Arg::initialize("hnt:qv", longOpts, longEnd, argc, argv);
     arg.versionHelp(usage, VERSION, 1);
 
