@@ -11,11 +11,11 @@ catch (int ret)                 // handle the known exceptions
 }
 catch (exception const &exc)
 {
-    cerr << exc.what() << '\n';
+    cerr << "icm-spch: " << exc.what() << '\n';
     return 1;
 }
 catch (...)                     // and handle an unexpected exception
 {
-    cerr << "unexpected exception\n";
+    cerr << "icm-spch: unexpected exception\n";
     return 1;
 }
