@@ -13,7 +13,7 @@ namespace
         Arg::LongOption{"keep",             'k'},
         Arg::LongOption{"list",             'l'},
         Arg::LongOption{"no-topdir",        'n'},
-        Arg::LongOption{"options",          'o'},
+        Arg::LongOption{"option",           'o'},
         Arg::LongOption{"precompile",       'p'},
         Arg::LongOption{"quiet",            'q'},
         Arg::LongOption{"required",         'r'},
