@@ -4,5 +4,6 @@
 // static
 bool Options::keep(std::string const &spec)
 {
-    return s_keep << spec;
+    wmsg << "keep(...) is deprecated. Use unused()" << endl;
+    return unused(spec);
 }
