@@ -3,7 +3,11 @@
 
 #include <iosfwd>
 
-#include "../../tmp/build/datetime/datetime"
+#ifdef fbb
+    #include <bobcat/datetime>
+#else
+    #include "../../tmp/build/datetime/datetime"
+#endif
 
 #include "../options/options.h"
 #include "../support/support.h"
@@ -27,7 +31,7 @@ class Process: private Support
         int run();                  // returns 0 on success, for main()
 
     private:
-        int spch() const;           // construct/inspect the spch file
+        int spch() const;           // construct the spch file
 
         int precompile();           // precompile the all.ih file
         int softLinks() const;      // create the soft-links to the SPCH
