@@ -7,7 +7,11 @@
 #include <filesystem>
 #include <unordered_set>
 
-#include "../../tmp/build/exception/exception"
+#ifdef fbb
+    #include <bobcat/exception>
+#else
+    #include "../../tmp/build/exception/exception"
+#endif
 
 namespace std
 {
