@@ -25,17 +25,7 @@ try
 
     unAssembler.run(arg.basename());
 }
-catch (exception const &exc)
-{
-    cout << '\n' <<
-            exc.what() << '\n';
-    return 1;
-}
-catch (int exitValue)
-{
-    return Arg::instance().option("hv") ? 0 : exitValue;
-}
 catch (...)
 {
-    return 1;
+    return handleException();
 }
